@@ -16,9 +16,24 @@
  *
  */
 
-import React from 'react'
-import ReactDOM from 'react-dom'
+import React from 'react';
+import ReactDOM from 'react-dom';
+import { BrowserRouter } from 'react-router-dom';
 
-import App from './App'
+import { ErrorBoundary } from '@/error';
+import { VersionContextProvider } from '@/store';
 
-ReactDOM.render(<App />, document.getElementById('app'))
+import App from './App';
+
+import './index.css';
+
+ReactDOM.render(
+  <BrowserRouter>
+    <ErrorBoundary>
+      <VersionContextProvider>
+        <App />
+      </VersionContextProvider>
+    </ErrorBoundary>
+  </BrowserRouter>,
+  document.getElementById('app'),
+);
