@@ -15,22 +15,21 @@
  * limitations under the License.
  *
  */
-const path = require('path')
-const webpack = require('webpack')
-const BundleAnalyzerPlugin = require('webpack-bundle-analyzer').BundleAnalyzerPlugin
-const HtmlWebpackPlugin = require('html-webpack-plugin')
-const CopyPlugin = require('copy-webpack-plugin')
-const { CleanWebpackPlugin } = require('clean-webpack-plugin')
-const ESLintPlugin = require('eslint-webpack-plugin')
-const MiniCssExtractPlugin = require('mini-css-extract-plugin')
-const CssMinimizerPlugin = require('css-minimizer-webpack-plugin')
-const TerserPlugin = require('terser-webpack-plugin')
+const path = require('path');
+const webpack = require('webpack');
+const BundleAnalyzerPlugin = require('webpack-bundle-analyzer').BundleAnalyzerPlugin;
+const HtmlWebpackPlugin = require('html-webpack-plugin');
+const CopyPlugin = require('copy-webpack-plugin');
+const { CleanWebpackPlugin } = require('clean-webpack-plugin');
+const MiniCssExtractPlugin = require('mini-css-extract-plugin');
+const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
+const TerserPlugin = require('terser-webpack-plugin');
 
 module.exports = (env = {}) => {
-  const optionalPlugins = []
+  const optionalPlugins = [];
 
   if (env.ANALYZE_BUILD === 1) {
-    optionalPlugins.push(new BundleAnalyzerPlugin())
+    optionalPlugins.push(new BundleAnalyzerPlugin());
   }
 
   return {
@@ -40,16 +39,10 @@ module.exports = (env = {}) => {
     module: {
       rules: [
         {
-          test: /\.jsx?$/,
-          exclude: [/node_modules/, /packages/, /cypress/, /^config$/],
+          test: /\.(tsx?|jsx?)$/,
+          exclude: [/node_modules/, /packages/, /^config$/],
           use: {
             loader: 'babel-loader',
-            options: {
-              babelrc: false,
-              cacheDirectory: false,
-              presets: ['@babel/preset-env', '@babel/preset-react', '@babel/preset-flow'],
-              plugins: ['@babel/plugin-transform-runtime']
-            }
           },
         },
         {
@@ -58,52 +51,12 @@ module.exports = (env = {}) => {
             // !WARNING! We only use style-loader for DEV MODE!
             // 'style-loader',
             MiniCssExtractPlugin.loader,
-            {
-              loader: 'css-loader',
-              options: {
-                modules: true,
-                importLoaders: 1,
-              }
-            }
-          ]
-        },
-        {
-          test: /\.scss$/,
-          use: [
-            {
-              loader: MiniCssExtractPlugin.loader,
-            },
-            {
-              loader: require.resolve('css-loader'),
-              options: {
-                importLoaders: 1,
-              },
-            },
-            {
-              loader: require.resolve('postcss-loader'),
-              options: {
-                postcssOptions: {
-                  plugins: [require('autoprefixer'), require('cssnano')({ preset: 'default' })],
-                },
-              },
-            },
-            {
-              loader: 'resolve-url-loader'
-            },
-            {
-              loader: 'sass-loader',
-              options: {
-                implementation: require('node-sass'),
-                sourceMap: true,
-                additionalData: '@import "@/styles/theme.scss";',
-              }
-            }
+            'css-loader',
           ],
-          // sideEffects: true
         },
         {
           test: /\.html$/,
-          use: ['html-loader']
+          use: ['html-loader'],
         },
         {
           test: /\.(png|gif|jpe?g)$/,
@@ -116,10 +69,7 @@ module.exports = (env = {}) => {
         {
           test: /\.(eot|ttf|woff|woff2|svg)$/,
           loader: require.resolve('file-loader'),
-          include: [
-            path.resolve(__dirname, './src/fonts/'),
-            path.resolve(__dirname, './node_modules/')
-          ],
+          include: [path.resolve(__dirname, './src/fonts/'), path.resolve(__dirname, './node_modules/')],
           options: {
             name: '[name].[ext]',
             outputPath: 'fonts/',
@@ -133,22 +83,21 @@ module.exports = (env = {}) => {
         },
         {
           test: /\.po$/,
-          use: ['@lingui/loader']
-        }
-      ]
+          use: ['@lingui/loader'],
+        },
+      ],
     },
     resolve: {
       alias: {
         '@': path.resolve(__dirname, './src/'),
-        '@config': path.resolve(__dirname, './config/'),
       },
       // modules: ['node_modules'],
-      extensions: ['*', '.js', '.jsx', '.scss']
+      extensions: ['*', '.js', '.jsx', '.ts', '.tsx'],
     },
     output: {
       path: path.resolve(__dirname, './dist'),
       filename: '[name].[hash].js',
-      publicPath: '/'
+      publicPath: '/',
     },
     optimization: {
       minimize: true,
@@ -161,9 +110,9 @@ module.exports = (env = {}) => {
             sourceMap: false,
             compress: {
               drop_console: true,
-            }
-          }
-        })
+            },
+          },
+        }),
       ],
     },
     plugins: [
@@ -171,21 +120,15 @@ module.exports = (env = {}) => {
       new webpack.HotModuleReplacementPlugin(),
       new MiniCssExtractPlugin({ filename: '[name].[hash].css' }),
       new HtmlWebpackPlugin({
-        template: path.resolve(__dirname, './src/index-production.html'),
+        template: path.resolve(__dirname, './src/index.html'),
         filename: 'index.html',
         favicon: path.resolve(__dirname, './src/images/favicon.ico'),
       }),
       new webpack.EnvironmentPlugin({ ...process.env }),
       new CopyPlugin({
-        patterns: [
-          { from: 'src/images/logo.svg', to: 'logo.svg' },
-        ],
+        patterns: [{ from: 'src/images/logo.svg', to: 'logo.svg' }],
       }),
-      new ESLintPlugin({
-        context: path.resolve(__dirname, './'),
-        exclude: ['dist', 'packages', 'cypress', 'config', 'node_modules']
-      }),
-      ...optionalPlugins
-    ]
-  }
-}
+      ...optionalPlugins,
+    ],
+  };
+};
